##  Advanced Settings
The Advanced Settings category in the administration area includes sections listed in the following table.
Section | Description | Related Information
---|---|---
Automations | Configure no-code automations to initiate automated trigger-based actions. |  [Automations](https://help.sap.com/docs/leanix/ea/automations?locale=en-US&state=PRODUCTION&version=CLOUD "Configure no-code automations to streamline your workflows.")
Calculations | Configure calculations to populate fact sheet fields based on values from other fields. Use calculation templates for common scenarios or configure your own to define custom logic. |  [Calculations](https://help.sap.com/docs/leanix/ea/calculations?locale=en-US&state=PRODUCTION&version=CLOUD "Calculations let you populate fact sheet fields based on values from other fields. Use calculation templates for common scenarios or configure your own to define custom logic.")
Export | Export workspace snapshots and view the export history. |  [Export](https://help.sap.com/docs/leanix/ea/export?locale=en-US&state=PRODUCTION&version=CLOUD "Export your workspace data and view the export history.")
KPIs | Configure KPIs based on the workspace data and then preview them in dashboards. |  [KPIs](https://help.sap.com/docs/leanix/ea/kpis?locale=en-US&state=PRODUCTION&version=CLOUD "Configure KPIs and display them on dashboards to track enterprise architecture metrics.")
Managed Code | View and manage all custom code configurations used in automations, calculations, and webhooks across your workspace. Monitor execution logs to track history, troubleshoot issues, and ensure your code runs as expected. | [Managed Code](https://help.sap.com/docs/leanix/ea/managed-code?locale=en-US&state=PRODUCTION&version=CLOUD "View and manage all custom code configurations used in automations, calculations, and webhooks across your workspace. Monitor execution logs to track history, troubleshoot issues, and ensure your code runs as expected.")
Notifications Center | Configure notification settings for the workspace. |  [Notifications Center](https://help.sap.com/docs/leanix/ea/notifications-center?locale=en-US&state=PRODUCTION&version=CLOUD "Configure notification settings for your workspace.")
Optional Features and Early Access | Activate or deactivate optional features and features in early adoption release. Use these features and provide your feedback. |  [SAP LeanIX Architecture and Road Map Planning](https://help.sap.com/docs/leanix/ea/sap-leanix-architecture-and-road-map-planning?locale=en-US&state=PRODUCTION&version=CLOUD "The SAP LeanIX Architecture and Road Map Planning enhances SAP LeanIX Application Portfolio Management by offering advanced features for seamless planning and execution of transformation initiatives in enterprise architecture management.") [Objective Modeling Guidelines](https://help.sap.com/docs/leanix/ea/objective-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to model objectives. This includes best practices and applicable use cases, and common antipatterns.") [Storing Resources on Fact Sheets](https://help.sap.com/docs/leanix/ea/collaborating-and-managing-data-in-fact-sheets?locale=en-US&state=PRODUCTION&version=CLOUD#loio27592c207a441014b142ca56bfa9decf__storing_resources_on_fact_sheets) [AI Capabilities](https://help.sap.com/docs/leanix/ea/ai-capabilities?locale=en-US&state=PRODUCTION&version=CLOUD "AI capabilities in SAP LeanIX automate documentation tasks, offer contextual insights, and support natural language queries to streamline enterprise architecture management. Use it to boost efficiency, reduce manual work, and maintain compliance with data privacy and ethical standards.") [ESG Capability Modeling Guidelines](https://help.sap.com/docs/leanix/ea/esg-capability-modeling-guidelines?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to implement sustainable IT transformation using the ESG capability optional feature.")
Portals | Configure self-service portals to grant access to specific information to certain users without inviting them to the workspace. |  [Portals](https://help.sap.com/docs/leanix/ea/portals?locale=en-US&state=PRODUCTION&version=CLOUD "Create customizable, secure entry points that provide non-IT users with curated enterprise architecture information, resources, and visual assets outside the main application.")
Reports | View and configure access permissions for reports downloaded from the SAP LeanIX Store. |  [Downloading Reports from the SAP LeanIX Store](https://help.sap.com/docs/leanix/ea/download-reports?locale=en-US&state=PRODUCTION&version=CLOUD "Download custom reports from the SAP LeanIX Store and make them available to all workspace users.")
To-Dos | Get an overview of to-dos that enable you to assign tasks to users. |  [To-Dos](https://help.sap.com/docs/leanix/ea/to-dos-administration?locale=en-US&state=PRODUCTION&version=CLOUD "As an admin, learn how to create approval to-dos and manage all the to-do items in the administration area.")
Transformations | Configure transformation templates and general settings for transformations. |  [Transformations](https://help.sap.com/docs/leanix/ea/transformations?locale=en-US&state=PRODUCTION&version=CLOUD "Learn how to define and manage Transformations in the Initiative Fact Sheet.")
Workspace Views | Configure workspace views to help users limit the scope of displayed information. |  [Workspace Views](https://help.sap.com/docs/leanix/ea/workspace-views-configuration?locale=en-US&state=PRODUCTION&version=CLOUD "Workspace views help users limit the scope of displayed information and focus on their current tasks. Configure custom workspace views tailored to typical use cases and scenarios, specifying which dashboards, fact sheets, reports, and diagrams to include.")


